/*
 * 1394-Based Digital Camera Control Library
 *
 * Camera Control headers for Linux
 *  
 * Written by Damien Douxchamps <ddouxchamps@users.sf.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __DC1394_CONTROL_LINUX_H__
#define __DC1394_CONTROL_LINUX_H__

#ifdef __cplusplus
extern "C" {
#endif

dc1394error_t
dc1394_camera_get_linux_port(dc1394camera_t *camera, uint32_t *port);

#ifdef __cplusplus
}
#endif

#endif
